@@ -108,8 +108,7 @@ def _convert_legacy_to_enhanced(
             # Only root-level attributes
             if len(attr_item['path']) > 0:
                 continue
-            keyword: str = attr_item['keyword']
-            tag = tag_for_keyword(keyword)
+            tag = tag_for_keyword(attr_item['keyword'])
             if tag in ignored_attributes:
                 continue
             mf_attributes.append(tag)
@@ -193,9 +192,9 @@ def _convert_legacy_to_enhanced(
         frame_type_item.PixelRepresentation = pixel_representation
         frame_type_item.VolumetricProperties = volumetric_properties
         if frame_type[0] == 'ORIGINAL':
-            frame_type_item.FrameVolumeBasedCalculationTechnique = 'NONE'
+            frame_type_item.VolumeBasedCalculationTechnique = 'NONE'
         else:
-            frame_type_item.FrameVolumeBasedCalculationTechnique = 'MIXED'
+            frame_type_item.VolumeBasedCalculationTechnique = 'MIXED'
 
         if sop_class_uid == '1.2.840.10008.5.1.4.1.1.4.4':
             # MR Image Frame Type (M)
