@@ -1,9 +1,15 @@
 """Content items for Structured Report document instances."""
-from typing import Optional, Sequence, Union
+import logging
+from copy import deepcopy
+from typing import cast, Optional, Sequence, Union
 
 import numpy as np
-from pydicom._storage_sopclass_uids import SegmentationStorage
+from pydicom._storage_sopclass_uids import (
+    SegmentationStorage,
+    VLWholeSlideMicroscopyImageStorage
+)
 from pydicom.dataset import Dataset
+from pydicom.sr.codedict import codes
 from pydicom.sr.coding import Code
 from highdicom.sr.coding import CodedConcept
 from highdicom.sr.enum import (
@@ -11,7 +17,9 @@ from highdicom.sr.enum import (
     GraphicTypeValues3D,
     PixelOriginInterpretationValues,
     RelationshipTypeValues,
+    ValueTypeValues,
 )
+from highdicom.sr.utils import find_content_items
 from highdicom.sr.value_types import (
     CodeContentItem,
     CompositeContentItem,
@@ -24,6 +32,9 @@ from highdicom.sr.value_types import (
 )
 
 
+logger = logging.getLogger(__name__)
+
+
 def _check_valid_source_image_dataset(dataset: Dataset) -> None:
     """Raise an error if the image is not a valid source image reference.
 
@@ -46,17 +57,18 @@ def _check_valid_source_image_dataset(dataset: Dataset) -> None:
         measurement, segmentation, or region.
 
     """
-    # Check that there is some form of pixel data present
+    # Check that some of the image pixel description attributes are present
     pixel_data_keywords = [
-        'PixelData',
-        'FloatPixelData',
-        'DoubleFloatPixelData'
+        'Rows',
+        'Columns',
+        'SamplesPerPixel',
+        'PixelRepresentation',
     ]
     if not any(hasattr(dataset, attr) for attr in pixel_data_keywords):
         raise ValueError(
             'Dataset does not represent a valid source image for '
             'a measurement, segmentation, or region because it '
-            'contains no pixel data.'
+            'lacks image pixel description attributes.'
         )
     # Check for obviously invalid modalities
     disallowed_modalities = [
@@ -101,22 +113,22 @@ class LongitudinalTemporalOffsetFromEvent(NumContentItem):
 
     def __init__(
         self,
-        value: Optional[Union[int, float]],
-        unit: Optional[Union[CodedConcept, Code]] = None,
-        event_type: Optional[Union[CodedConcept, Code]] = None
+        value: Union[int, float],
+        unit: Union[CodedConcept, Code],
+        event_type: Union[CodedConcept, Code]
     ) -> None:
         """
         Parameters
         ----------
-        value: Union[int, float], optional
-            offset in time from a particular event of significance
-        unit: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code], optional
-            unit of time, e.g., "Days" or "Seconds"
-        event_type: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code], optional
-            type of event to which offset is relative,
+        value: Union[int, float]
+            Offset in time from a particular event of significance
+        unit: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code]
+            Unit of time, e.g., "Days" or "Seconds"
+        event_type: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code]
+            Type of event to which offset is relative,
             e.g., "Baseline" or "Enrollment"
 
-        """  # noqa
+        """  # noqa: E501
         super().__init__(
             name=CodedConcept(
                 value='128740',
@@ -138,6 +150,35 @@ class LongitudinalTemporalOffsetFromEvent(NumContentItem):
         )
         self.ContentSequence = ContentSequence([event_type_item])
 
+    @classmethod
+    def from_dataset(
+        cls,
+        dataset: Dataset
+    ) -> 'LongitudinalTemporalOffsetFromEvent':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.LongitudinalTemporalOffsetFromEvent
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(
+        cls,
+        dataset: Dataset
+    ) -> 'LongitudinalTemporalOffsetFromEvent':
+        item = super()._from_dataset_base(dataset)
+        return cast(LongitudinalTemporalOffsetFromEvent, item)
+
 
 class SourceImageForMeasurement(ImageContentItem):
 
@@ -146,11 +187,11 @@ class SourceImageForMeasurement(ImageContentItem):
     """
 
     def __init__(
-            self,
-            referenced_sop_class_uid: str,
-            referenced_sop_instance_uid: str,
-            referenced_frame_numbers: Optional[Sequence[int]] = None
-        ):
+        self,
+        referenced_sop_class_uid: str,
+        referenced_sop_instance_uid: str,
+        referenced_frame_numbers: Optional[Sequence[int]] = None
+    ):
         """
         Parameters
         ----------
@@ -158,7 +199,7 @@ class SourceImageForMeasurement(ImageContentItem):
             SOP Class UID of the referenced image object
         referenced_sop_instance_uid: str
             SOP Instance UID of the referenced image object
-        referenced_frame_numbers: Sequence[int], optional
+        referenced_frame_numbers: Union[Sequence[int], None], optional
             numbers of the frames to which the reference applies in case the
             referenced image is a multi-frame image
 
@@ -198,7 +239,7 @@ class SourceImageForMeasurement(ImageContentItem):
         ----------
         image: pydicom.dataset.Dataset
             Dataset representing the image to be referenced
-        referenced_frame_numbers: Sequence[int], optional
+        referenced_frame_numbers: Union[Sequence[int], None], optional
             numbers of the frames to which the reference applies in case the
             referenced image is a multi-frame image
 
@@ -220,6 +261,29 @@ class SourceImageForMeasurement(ImageContentItem):
             referenced_frame_numbers=referenced_frame_numbers
         )
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'SourceImageForMeasurement':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.SourceImageForMeasurement
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'SourceImageForMeasurement':
+        item = super()._from_dataset_base(dataset)
+        return cast(SourceImageForMeasurement, item)
+
 
 class SourceImageForRegion(ImageContentItem):
 
@@ -228,11 +292,11 @@ class SourceImageForRegion(ImageContentItem):
     """
 
     def __init__(
-            self,
-            referenced_sop_class_uid: str,
-            referenced_sop_instance_uid: str,
-            referenced_frame_numbers: Optional[Sequence[int]] = None
-        ):
+        self,
+        referenced_sop_class_uid: str,
+        referenced_sop_instance_uid: str,
+        referenced_frame_numbers: Optional[Sequence[int]] = None
+    ):
         """
         Parameters
         ----------
@@ -240,7 +304,7 @@ class SourceImageForRegion(ImageContentItem):
             SOP Class UID of the referenced image object
         referenced_sop_instance_uid: str
             SOP Instance UID of the referenced image object
-        referenced_frame_numbers: Sequence[int], optional
+        referenced_frame_numbers: Union[Sequence[int], None], optional
             numbers of the frames to which the reference applies in case the
             referenced image is a multi-frame image
 
@@ -280,7 +344,7 @@ class SourceImageForRegion(ImageContentItem):
         ----------
         image: pydicom.dataset.Dataset
             Dataset representing the image to be referenced
-        referenced_frame_numbers: Sequence[int], optional
+        referenced_frame_numbers: Union[Sequence[int], None], optional
             numbers of the frames to which the reference applies in case the
             referenced image is a multi-frame image
 
@@ -302,6 +366,29 @@ class SourceImageForRegion(ImageContentItem):
             referenced_frame_numbers=referenced_frame_numbers
         )
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'SourceImageForRegion':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.SourceImageForRegion
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'SourceImageForRegion':
+        item = super()._from_dataset_base(dataset)
+        return cast(SourceImageForRegion, item)
+
 
 class SourceImageForSegmentation(ImageContentItem):
 
@@ -310,11 +397,11 @@ class SourceImageForSegmentation(ImageContentItem):
     """
 
     def __init__(
-            self,
-            referenced_sop_class_uid: str,
-            referenced_sop_instance_uid: str,
-            referenced_frame_numbers: Optional[Sequence[int]] = None
-        ) -> None:
+        self,
+        referenced_sop_class_uid: str,
+        referenced_sop_instance_uid: str,
+        referenced_frame_numbers: Optional[Sequence[int]] = None
+    ) -> None:
         """
         Parameters
         ----------
@@ -322,7 +409,7 @@ class SourceImageForSegmentation(ImageContentItem):
             SOP Class UID of the referenced image object
         referenced_sop_instance_uid: str
             SOP Instance UID of the referenced image object
-        referenced_frame_numbers: Sequence[int], optional
+        referenced_frame_numbers: Union[Sequence[int], None], optional
             numbers of the frames to which the reference applies in case the
             referenced image is a multi-frame image
 
@@ -362,7 +449,7 @@ class SourceImageForSegmentation(ImageContentItem):
         ----------
         image: pydicom.dataset.Dataset
             Dataset representing the image to be referenced
-        referenced_frame_numbers: Sequence[int], optional
+        referenced_frame_numbers: Union[Sequence[int], None], optional
             numbers of the frames to which the reference applies in case the
             referenced image is a multi-frame image
 
@@ -384,6 +471,29 @@ class SourceImageForSegmentation(ImageContentItem):
             referenced_frame_numbers=referenced_frame_numbers
         )
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'SourceImageForSegmentation':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.SourceImageForSegmentation
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'SourceImageForSegmentation':
+        item = super()._from_dataset_base(dataset)
+        return cast(SourceImageForSegmentation, item)
+
 
 class SourceSeriesForSegmentation(UIDRefContentItem):
 
@@ -433,6 +543,29 @@ class SourceSeriesForSegmentation(UIDRefContentItem):
             referenced_series_instance_uid=image.SeriesInstanceUID,
         )
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'SourceSeriesForSegmentation':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.SourceSeriesForSegmentation
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'SourceSeriesForSegmentation':
+        item = super()._from_dataset_base(dataset)
+        return cast(SourceSeriesForSegmentation, item)
+
 
 class ImageRegion(ScoordContentItem):
 
@@ -457,9 +590,9 @@ class ImageRegion(ScoordContentItem):
         graphic_data: numpy.ndarray
             array of ordered spatial coordinates, where each row of the array
             represents a (column, row) coordinate pair
-        source_image: highdicom.sr.template.SourceImageForRegion
+        source_image: highdicom.sr.SourceImageForRegion
             source image to which `graphic_data` relates
-        pixel_origin_interpretation: Union[highdicom.sr.PixelOriginInterpretationValues, str], optional
+        pixel_origin_interpretation: Union[highdicom.sr.PixelOriginInterpretationValues, str, None], optional
             whether pixel coordinates specified by `graphic_data` are defined
             relative to the total pixel matrix
             (``highdicom.sr.PixelOriginInterpretationValues.VOLUME``) or
@@ -468,7 +601,7 @@ class ImageRegion(ScoordContentItem):
             of the source image
             (default: ``highdicom.sr.PixelOriginInterpretationValues.VOLUME``)
 
-        """  # noqa
+        """  # noqa: E501
         graphic_type = GraphicTypeValues(graphic_type)
         if graphic_type == GraphicTypeValues.MULTIPOINT:
             raise ValueError(
@@ -478,15 +611,19 @@ class ImageRegion(ScoordContentItem):
             raise TypeError(
                 'Argument "source_image" must have type SourceImageForRegion.'
             )
-        if pixel_origin_interpretation is None:
-            pixel_origin_interpretation = PixelOriginInterpretationValues.VOLUME
         if pixel_origin_interpretation == PixelOriginInterpretationValues.FRAME:
-            if (not hasattr(source_image, 'ReferencedFrameNumber') or
-                    source_image.ReferencedFrameNumber is None):
+            ref_sop_item = source_image.ReferencedSOPSequence[0]
+            if (not hasattr(ref_sop_item, 'ReferencedFrameNumber') or
+                    ref_sop_item.ReferencedFrameNumber is None):
                 raise ValueError(
                     'Frame number of source image must be specified when value '
                     'of argument "pixel_origin_interpretation" is "FRAME".'
                 )
+        ref_sop_instance_item = source_image.ReferencedSOPSequence[0]
+        ref_sop_class_uid = ref_sop_instance_item.ReferencedSOPClassUID
+        if (ref_sop_class_uid == VLWholeSlideMicroscopyImageStorage and
+                pixel_origin_interpretation is None):
+            pixel_origin_interpretation = PixelOriginInterpretationValues.VOLUME
         super().__init__(
             name=CodedConcept(
                 value='111030',
@@ -500,6 +637,29 @@ class ImageRegion(ScoordContentItem):
         )
         self.ContentSequence = [source_image]
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'ImageRegion':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.ImageRegion
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'ImageRegion':
+        item = super()._from_dataset_base(dataset)
+        return cast(ImageRegion, item)
+
 
 class ImageRegion3D(Scoord3DContentItem):
 
@@ -524,7 +684,7 @@ class ImageRegion3D(Scoord3DContentItem):
         frame_of_reference_uid: str
             UID of the frame of reference
 
-        """  # noqa
+        """  # noqa: E501
         graphic_type = GraphicTypeValues3D(graphic_type)
         if graphic_type == GraphicTypeValues3D.MULTIPOINT:
             raise ValueError(
@@ -546,6 +706,29 @@ class ImageRegion3D(Scoord3DContentItem):
             relationship_type=RelationshipTypeValues.CONTAINS
         )
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'ImageRegion3D':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.ImageRegion3D
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'ImageRegion3D':
+        item = super()._from_dataset_base(dataset)
+        return cast(ImageRegion3D, item)
+
 
 class VolumeSurface(Scoord3DContentItem):
 
@@ -573,16 +756,16 @@ class VolumeSurface(Scoord3DContentItem):
         frame_of_reference_uid: str
             unique identifier of the frame of reference within which the
             coordinates are defined
-        source_images: Sequence[highdicom.sr.SourceImageForSegmentation], optional
+        source_images: Union[Sequence[highdicom.sr.SourceImageForSegmentation], None], optional
             source images for segmentation
-        source_series: highdicom.sr.SourceSeriesForSegmentation, optional
+        source_series: Union[highdicom.sr.SourceSeriesForSegmentation, None], optional
             source series for segmentation
 
         Note
         ----
         Either one or more source images or one source series must be provided.
 
-        """  # noqa
+        """  # noqa: E501
         graphic_type = GraphicTypeValues3D(graphic_type)
         if graphic_type != GraphicTypeValues3D.ELLIPSOID:
             raise ValueError(
@@ -621,6 +804,29 @@ class VolumeSurface(Scoord3DContentItem):
                 '"source_images" or "source_series".'
             )
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'VolumeSurface':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.VolumeSurface
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'VolumeSurface':
+        item = super()._from_dataset_base(dataset)
+        return cast(VolumeSurface, item)
+
 
 class RealWorldValueMap(CompositeContentItem):
 
@@ -672,6 +878,29 @@ class RealWorldValueMap(CompositeContentItem):
             referenced_sop_instance_uid=value_map_dataset.SOPInstanceUID,
         )
 
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'RealWorldValueMap':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.RealWorldValueMap
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'RealWorldValueMap':
+        item = super()._from_dataset_base(dataset)
+        return cast(RealWorldValueMap, item)
+
 
 class FindingSite(CodeContentItem):
 
@@ -688,14 +917,13 @@ class FindingSite(CodeContentItem):
         ----------
         anatomic_location: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code]
             coded anatomic location (region or structure)
-        laterality: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code], optional
-            coded laterality
-            (see `CID 244 <http://dicom.nema.org/medical/dicom/current/output/chtml/part16/sect_CID_244.html>`_
+        laterality: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code, None], optional
+            coded laterality (see :dcm:`CID 244 <part16/sect_CID_244.html>`
             "Laterality" for options)
-        topographical_modifier: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code], optional
+        topographical_modifier: Union[highdicom.sr.CodedConcept, pydicom.sr.coding.Code, None], optional
             coded modifier of anatomic location
 
-        """  # noqa
+        """  # noqa: E501
         super().__init__(
             name=CodedConcept(
                 value='363698007',
@@ -730,6 +958,61 @@ class FindingSite(CodeContentItem):
                 )
                 self.ContentSequence.append(modifier_item)
 
+    @property
+    def topographical_modifier(self) -> Union[CodedConcept, None]:
+        matches = find_content_items(
+            self,
+            name=codes.SCT.TopographicalModifier,
+            value_type=ValueTypeValues.CODE
+        )
+        if len(matches) > 0:
+            return matches[0].value
+        elif len(matches) > 1:
+            logger.warning(
+                'found more than one "Topographical Modifier" content item '
+                'in "Finding Site" content item'
+            )
+        return None
+
+    @property
+    def laterality(self) -> Union[CodedConcept, None]:
+        matches = find_content_items(
+            self,
+            name=codes.SCT.Laterality,
+            value_type=ValueTypeValues.CODE
+        )
+        if len(matches) > 0:
+            return matches[0].value
+        elif len(matches) > 1:
+            logger.warning(
+                'found more than one "Laterality" content item '
+                'in "Finding Site" content item'
+            )
+        return None
+
+    @classmethod
+    def from_dataset(cls, dataset: Dataset) -> 'FindingSite':
+        """Construct object from an existing dataset.
+
+        Parameters
+        ----------
+        dataset: pydicom.dataset.Dataset
+            Dataset representing an SR Content Item with value type SCOORD
+
+        Returns
+        -------
+        highdicom.sr.FindingSite
+            Constructed object
+
+        """
+        dataset_copy = deepcopy(dataset)
+        return cls._from_dataset(dataset_copy)
+
+    @classmethod
+    def _from_dataset(cls, dataset: Dataset) -> 'FindingSite':
+        item = super()._from_dataset_base(dataset)
+        return cast(FindingSite, item)
+
 
 class ReferencedSegmentationFrame(ContentSequence):
 
@@ -937,19 +1220,19 @@ class ReferencedSegment(ContentSequence):
             SOP Instance UID of the referenced segmentation object
         segment_number: int
             number of the segment to which the reference applies
-        frame_numbers: Sequence[int], optional
+        frame_numbers: Union[Sequence[int], None], optional
             numbers of the frames to which the reference applies
             (in case a segmentation instance is referenced)
-        source_images: Sequence[highdicom.sr.SourceImageForSegmentation], optional
+        source_images: Union[Sequence[highdicom.sr.SourceImageForSegmentation], None], optional
             source images for segmentation
-        source_series: highdicom.sr.SourceSeriesForSegmentation, optional
+        source_series: Union[highdicom.sr.SourceSeriesForSegmentation, None], optional
             source series for segmentation
 
         Note
         ----
         Either `source_images` or `source_series` must be provided.
 
-        """  # noqa
+        """  # noqa: E501
         super().__init__()
         segment_item = ImageContentItem(
             name=CodedConcept(
@@ -1002,7 +1285,7 @@ class ReferencedSegment(ContentSequence):
             segment
         segment_number: int
             number of the segment to reference within the provided dataset
-        frame_numbers: Optional[Sequence[int]], optional
+        frame_numbers: Union[Sequence[int], None], optional
             list of frames in the segmentation dataset to reference. If
             not provided, the reference is assumed to apply to all frames
             of the given segment number. Note that frame numbers are
